@@ -287,6 +287,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
                     "Tai\u0161o",
                     "\u0160ova",
                     "Haisei",
+                    "",
                 }
             },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
@@ -331,6 +332,25 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 hiljada",
+                    "00 hiljada",
+                    "000 hiljada",
+                    "0 milion",
+                    "00 milion",
+                    "000 milion",
+                    "0 milijarda",
+                    "00 milijarda",
+                    "000 milijarda",
+                    "0 bilion",
+                    "00 bilion",
+                    "000 bilion",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -379,6 +399,25 @@ public class FormatData_sr_Latn extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0hilj'.'",
+                    "00\u00a0hilj'.'",
+                    "000\u00a0hilj'.'",
+                    "0\u00a0mil'.'",
+                    "00\u00a0mil'.'",
+                    "000\u00a0mil'.'",
+                    "0\u00a0mlrd'.'",
+                    "00\u00a0mlrd'.'",
+                    "000\u00a0mlrd'.'",
+                    "0\u00a0bil'.'",
+                    "00\u00a0bil'.'",
+                    "000\u00a0bil'.'",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0}, letnje vreme" },
             { "DatePatterns",
@@ -409,6 +448,7 @@ public class FormatData_sr_Latn extends ListResourceBundle {
                     "Tai\u0161o",
                     "\u0160ova",
                     "Haisei",
+                    "",
                 }
             },
             { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
